@@ -15,9 +15,11 @@ while
       #: ${start=$i}              # capture the starting value of i
       ## some other commands      # needed for the loop
 #      mvn clean install -pl testsuite/integration/manualmode -Dts.manualmode=true -Dtest=ReplicatedFailoverTestCase#testBackupActivation
+       mvn -Pproxy test -Dtest=ServletInputStreamRequestBufferingTestCase -Dtest.dump=true
+# testBlockingServletInputStreamInParallel
+# testAsyncServletInputStreamInParallel
 #testBackupFailoverAfterFailback
 #testBackupActivation
-mvn test -Dtest=ServletSessionTestCase -Pproxy  -Dtest.ipv6=true
       (($? == 0 ))             # Place the loop ending test here.
 do :; done
 echo "The loop was executed $i times "
